@@ -11,5 +11,7 @@ int Arg__::setOptionType(string const &optString,
                                 static_cast<char>(longOption.d_optionChar) <<
                                 "' not found";
 
-    return optString[pos + 1] == ':' ? Required : None;
+    return optString[pos + 1] != ':' ? NoArg    :       // no :  -> no arg
+           optString[pos + 2] != ':' ? Required :       // no :: -> required
+                                       Optional;        //    else: optional
 }
