@@ -1,5 +1,6 @@
 #include "argconfig.ih"
 
-ArgConfig *ArgConfig::s_argconfig;
+unique_ptr<ArgConfig> ArgConfig::s_argConfig;
+
 char const ArgConfig::s_alreadyInitialized[] =
                         "ArgConfig::initialize(): already initialized";
