@@ -1,6 +1,7 @@
 #include <iostream>
 #include <string>
-#include "../binarysearch"
+
+#include <bobcat/binarysearch>
 
 using namespace std;
 
