@@ -2,6 +2,6 @@
 
 void CinInserter::parentRedirections()
 {
-    open(d_oChildInPipe.writeOnly(), OFdStreambuf::CLOSE_FD, d_bufSize);
+    reset(d_oChildInPipe.writeOnly(), OFdBuf::CLOSE_FD, d_bufSize);
 //    open(d_oChildInPipe.writeOnly(), d_bufSize);
 }
