@@ -1,6 +1,6 @@
 #include <iostream>
 
-#include "../fswap"
+#include <bobcat/fswap>
 
 using namespace FBB;
 
