@@ -2,6 +2,6 @@
 
 void ISharedStream::memInfo(std::ostream &out, char const *end) const
 {
-    static_cast<SharedStreambuf const *>(this)->memInfo(out);
+    static_cast<SharedBuf const *>(this)->memInfo(out);
     out << end;
 }
