@@ -1,9 +1,7 @@
 #include <iostream>
 #include <iomanip>
 
-//#include <bobcat/log>
-#include "../log"
-
+#include <bobcat/log>
 #include <bobcat/level>
 
 using namespace std;
@@ -50,5 +48,3 @@ int main()
     log.setLevel(2);
     log << level(2) << "in business again\n";
 }
-
-
