@@ -1,10 +1,10 @@
 #include "pipe.ih"
 
-void Pipe::writtenBy(int const *fd, size_t n)
+void Pipe::writtenBy(int const *fd, size_t nSwallow)
 {
     close(READ);
 
-    for (size_t idx = 0; idx != n; ++idx)
+    for (size_t idx = 0; idx != nSwallow; ++idx)
     {
         Redirector redirector{ d_fd[WRITE] };
         redirector.swallow(fd[idx]);
