@@ -1,4 +1,4 @@
 inline void SyslogStream::close()
 {
-    Syslogbuf::close();
+    eoi();
 }
